summaryrefslogtreecommitdiff
path: root/coverage/misc.py
diff options
context:
space:
mode:
Diffstat (limited to 'coverage/misc.py')
-rw-r--r--coverage/misc.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/coverage/misc.py b/coverage/misc.py
index b3b439c..534ef17 100644
--- a/coverage/misc.py
+++ b/coverage/misc.py
@@ -286,9 +286,9 @@ class ExceptionDuringRun(CoverageException):
# unittest.SkipTest doesn't exist in Python 2.6. We backport it with
# unittest2 in the coverage.py test suite. But for production, we don't need
-# to derive from SkipTest, so if it doesn't exist, just use object.
+# to derive from SkipTest, so if it doesn't exist, just use Exception.
-class StopEverything(getattr(unittest, 'SkipTest', object)):
+class StopEverything(getattr(unittest, 'SkipTest', Exception)):
"""An exception that means everything should stop.
This derives from SkipTest so that tests that spring this trap will be